Name:           ugene
Summary:        Integrated bioinformatics toolkit
Version:        52.0
Release:        %mkrel 1
License:        GPLv2+
Group:          Sciences/Biology
URL:            https://ugene.net/
Source0:        https://github.com/ugeneunipro/ugene/archive/%{version}/%{name}-%{version}.tar.gz
Source10:       ugene.wrapper

# Non-SSE2 x86 support dropped in 37.0:
# https://github.com/ugeneunipro/ugene/commit/f47fdf48c0a177dea5b5fada0ab51ff3a37e0f33
ExclusiveArch:  x86_64

BuildRequires:  pkgconfig(glu)
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5NetworkAuth)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
BuildRequires:  pkgconfig(Qt5ScriptTools)
BuildRequires:  pkgconfig(Qt5Sql)
BuildRequires:  pkgconfig(Qt5Svg)
BuildRequires:  pkgconfig(Qt5Test)
BuildRequires:  pkgconfig(Qt5WebSockets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(sqlite3)
BuildRequires:  pkgconfig(xtst)
BuildRequires:  pkgconfig(zlib)
BuildRequires:  procps-devel
BuildRequires:  qttools5
BuildRequires:  libstdc++-static-devel

Provides:       bundled(samtools) = 1.19.2

%description
Unipro UGENE is a cross-platform visual environment for DNA and protein
sequence analysis. UGENE integrates the most important bioinformatics
computational algorithms and provides an easy-to-use GUI for performing
complex analysis of the genomic data. One of the main features of UGENE
is a designer for custom bioinformatics workflows.


%prep
%autosetup -p1

%build
%qmake_qt5 -r \
        INSTALL_BINDIR=%{_bindir} \
        INSTALL_LIBDIR=%{_libdir} \
        INSTALL_DATADIR=%{_datadir} \
        INSTALL_MANDIR=%{_mandir} \
        UGENE_USE_SYSTEM_SQLITE=1 \
        UGENE_USE_BUNDLED_ZLIB=0 \
        UGENE_WITHOUT_NON_FREE=1 \
        UGENE_EXCLUDE_LIST_ENABLED=1
%make_build

%install
LIBAPPDIR=%{_libdir}/%{name}
make install \
    INSTALL="install -p"

# Some needed files are not installed.....
mkdir -p %{buildroot}$LIBAPPDIR
cp -a src/_release/* %{buildroot}$LIBAPPDIR
cp -a dist/%{name}-%{version}/* %{buildroot}$LIBAPPDIR/
rm -f %{buildroot}$LIBAPPDIR/*.a

# 1. manually move files...
pushd %{buildroot}
rm -f ./$LIBAPPDIR/LICENSE*

#  bindir
mkdir -p ./%{_bindir}
install -cpm 0755 %{SOURCE10} ./%{_bindir}/%{name}

#  data files
mkdir -p ./%{_datadir}/%{name}/
mv ./$LIBAPPDIR/data ./%{_datadir}/%{name}
ln -sf ../../../%{_datadir}/%{name} ./$LIBAPPDIR/data

#  hicolor
mkdir -p ./%{_datadir}/icons/hicolor/32x32/mimetypes/
mv ./$LIBAPPDIR/application-x-ugene-ext.png ./%{_datadir}/icons/hicolor/32x32/mimetypes/

#  mime
mkdir -p ./%{_datadir}/mime/packages
mv ./$LIBAPPDIR/application-x-ugene.xml ./%{_datadir}/mime/packages

#  man file
mkdir -p ./%{_mandir}/man1
mv ./$LIBAPPDIR/%{name}.1* ./%{_mandir}/man1

# desktop files
mkdir -p ./%{_datadir}/applications/
mv ./$LIBAPPDIR/%{name}.desktop ./%{_datadir}/applications/

#  icons
mkdir -p ./%{_datadir}/pixmaps
mv ./$LIBAPPDIR/%{name}.{png,xpm} ./%{_datadir}/pixmaps
popd

%files
%license	LICENSE.txt
%license	LICENSE.3rd_party.txt

%{_bindir}/%{name}
%dir %{_libdir}/%{name}/
%{_libdir}/%{name}/lib*.so
%dir %{_libdir}/%{name}/plugins/
%{_libdir}/%{name}/plugins/*.license
%{_libdir}/%{name}/plugins/*.plugin
%{_libdir}/%{name}/plugins/lib*.so
%{_libdir}/%{name}/ugene
%{_libdir}/%{name}/ugenecl
%{_libdir}/%{name}/ugenem
%{_libdir}/%{name}/ugeneui
%{_libdir}/%{name}/plugins_checker	
%{_libdir}/%{name}/transl_ru.qm
%{_libdir}/%{name}/transl_tr.qm
%dir	%{_datadir}/%{name}/
%{_datadir}/%{name}/data/
%{_libdir}/%{name}/data
%{_datadir}/applications/%{name}.desktop
%{_datadir}/pixmaps/ugene.*
%{_datadir}/icons/hicolor/32x32/mimetypes/application-x-ugene-ext.png
%{_datadir}/mime/packages/*.xml
%{_mandir}/man1/%{name}.1*


%changelog
* Fri Jan 24 2025 daviddavid <daviddavid> 52.0-1.mga10
+ Revision: 2141226
- new version: 52.0

* Thu Jun 27 2024 daviddavid <daviddavid> 50.0-1.mga10
+ Revision: 2077389
- new version: 50.0

* Tue Mar 05 2024 daviddavid <daviddavid> 49.1-1.mga10
+ Revision: 2047580
- new version: 49.1

* Thu Mar 23 2023 daviddavid <daviddavid> 45.1-2.mga9
+ Revision: 1950240
- drop no more needed by the project Qt5WebKit build dependency

* Mon Jan 02 2023 daviddavid <daviddavid> 45.1-1.mga9
+ Revision: 1928771
- new version: 45.1

* Sat Dec 17 2022 papoteur <papoteur> 45.00-1.mga9
+ Revision: 1924201
- new 45.00
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Fri Dec 18 2020 akien <akien> 37.0-1.mga8
+ Revision: 1660880
- Disable i586 build, upstream doesn't support non-SSE2 anymore
- Version 37.0

* Thu Dec 17 2020 umeabot <umeabot> 36.0-2.mga8
+ Revision: 1660117
- Rebuild for new Qt5

* Wed Oct 21 2020 akien <akien> 36.0-1.mga8
+ Revision: 1637688
- Version 36.0
+ umeabot <umeabot>
- Mageia 8 Mass Rebuild

* Tue Apr 02 2019 umeabot <umeabot> 1.30.0-3.mga7
+ Revision: 1385180
- Qt5 Rebuild

* Sun Sep 23 2018 umeabot <umeabot> 1.30.0-2.mga7
+ Revision: 1301504
- Mageia 7 Mass Rebuild

* Mon Jun 18 2018 akien <akien> 1.30.0-1.mga7
+ Revision: 1237806
- BR Qt5OpenGL
- Version 1.30.0

* Sat Dec 30 2017 akien <akien> 1.29.0-1.mga7
+ Revision: 1187886
- Version 1.29.0

* Sun Jun 25 2017 akien <akien> 1.26.3-1.mga6
+ Revision: 1108394
- Version 1.26.3

* Fri Feb 24 2017 akien <akien> 1.26.1-1.mga6
+ Revision: 1087664
- Version 1.26.1

* Fri Feb 10 2017 akien <akien> 1.26.0-1.mga6
+ Revision: 1085645
- Version 1.26.0

* Sun Oct 30 2016 akien <akien> 1.25.0-1.mga6
+ Revision: 1064234
- Version 1.25.0

* Mon Oct 03 2016 akien <akien> 1.24.2-1.mga6
+ Revision: 1058226
- Version 1.24.2

* Mon Oct 03 2016 neoclust <neoclust> 1.24.0-2.mga6
+ Revision: 1058208
- Do not build on ARM

* Sun Aug 14 2016 akien <akien> 1.24.0-1.mga6
+ Revision: 1046471
- Version 1.24.0

* Sat Apr 23 2016 akien <akien> 1.22.0-1.mga6
+ Revision: 1005702
- Version 1.22.0

* Sat Mar 19 2016 luigiwalser <luigiwalser> 1.21.0-1.mga6
+ Revision: 993029
- 1.21.0
- fix patch 4
+ tv <tv>
- rebuild for new libprocps
+ daviddavid <daviddavid>
- rebuild for new procps-ng 3.3.10

* Sun Dec 13 2015 akien <akien> 1.20.0-1.mga6
+ Revision: 910103
- Version 1.20.0

* Thu Dec 03 2015 akien <akien> 1.19.0-1.mga6
+ Revision: 907946
- Version 1.19.0

* Mon Sep 21 2015 akien <akien> 1.18.0-1.mga6
+ Revision: 882147
- Version 1.18.0
- Build with Qt5

* Sun Jan 18 2015 akien <akien> 1.15.1-1.mga5
+ Revision: 811281
- Version 1.15.1

* Thu Oct 16 2014 akien <akien> 1.14.2-1.mga5
+ Revision: 763959
- Version 1.14.2
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 1.14.1-3.mga5
+ Revision: 690025
- Mageia 5 Mass Rebuild

* Sat Sep 13 2014 akien <akien> 1.14.1-2.mga5
+ Revision: 675140
- Bugfix version 1.14.1

* Mon Sep 08 2014 akien <akien> 1.14.0-1.mga5
+ Revision: 673589
- Version 1.14.0
- Version 1.13.3

* Sun May 04 2014 akien <akien> 1.13.2-2.mga5
+ Revision: 619965
- Put back libraries (and binaries and translations...) in %%_libdir instead of %%_libexecdir

* Sun May 04 2014 akien <akien> 1.13.2-1.mga5
+ Revision: 619900
- imported package ugene

